@@ -70,4 +70,65 @@ find_cycles = function(g) {
         }
     }
     Cycles
-}
\ No newline at end of file
+}
+
+#' Define default effect for a given graph
+#' 
+#' @param graphres The graph object, should have vertex attributes "outcome" and "exposure"
+#' 
+#' @return A string that can be passed to \link{parse_effect}
+#' @export
+get_default_effect <- function(graphres) {
+    
+    rightvars <- V(graphres)[V(graphres)$leftside == 0 & names(V(graphres)) != "Ur"]
+    
+    expo <- V(graphres)[V(graphres)$exposure == 1]
+    outc <- V(graphres)[V(graphres)$outcome == 1]
+    effectpath <- all_simple_paths(graphres, from = expo, to = outc)
+    
+    if(length(outc) == 0 | length(expo) == 0) {
+        default.effect <- ""
+    } else {
+        ## default total effect
+        def.eff <- paste0(names(outc), "(")
+        stack <- c(")")
+        len.arg <- 0
+        for(j in 1:length(effectpath)) {
+            res <- ""
+            nvs <- length(effectpath[[j]])
+            for(k in max(1, nvs - 1):1) {
+                thisvar <- effectpath[[j]][k]
+                res <- paste0(res, names(thisvar), 
+                              ifelse(names(thisvar) == names(expo), 
+                                     " = %s", "("))
+                if(names(thisvar) == names(expo)) {
+                    len.arg <- len.arg + 1
+                } else {
+                    stack <- c(stack, ")")
+                }
+                
+            }
+            def.eff <- paste0(def.eff, res, 
+                              ifelse(j < length(effectpath), ", ", ""))
+            
+            #if((nvs - 1) > 1) {
+            #    stack <- c(stack, ")")
+            #}
+        }
+        def.eff <- paste(def.eff, paste(stack, collapse = ""), sep = "")
+        
+        def.eff <- paste0("p{", def.eff, "=1}")
+        
+        
+        default.effect <- paste(sapply(c(1, 0), function(x){
+            
+            arg2 <- lapply(1:len.arg, function(i) x)
+            arg1 <- def.eff
+            do.call(sprintf, c(arg1, arg2))
+            
+            
+            }), collapse = " - ")
+        
+    }
+        default.effect
+} 
